TextLayerData class
代表一个文本图层的数据结构
Constructors
Properties
- color ↔ Color
-
getter/setter pair
- fontSize ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- isSelected ↔ bool
-
getter/setter pair
- position → Offset
-
no setter
- relativePosition ↔ Offset
-
归一化坐标(0-1),相对于画布尺寸
例如:(0.5, 0.5) 表示画布中心
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text ↔ String
-
getter/setter pair
Methods
-
calculateAbsolutePosition(
Size canvasSize) → void - 根据画布尺寸计算绝对位置
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateAbsolutePosition(
Offset newPosition, Size canvasSize) → void - 更新绝对位置(内部会转换为归一化坐标)
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited